@@ -36,7 +36,7 @@ const TEST_ARRAY = [
 /**
  * Basic test that checks content of the DOM panel.
  */
-add_task(async function() {
+add_task(async function () {
   info("Test DOM Panel Array Expansion started");
 
   const { panel } = await addTestTab(TEST_PAGE_URL);
@@ -60,7 +60,11 @@ add_task(async function() {
       i++,
       `index ${name} is correct and sorted into the correct position`
     );
-    ok(typeof row.name === "number", "array index is displayed as a number");
+    Assert.strictEqual(
+      typeof row.name,
+      "number",
+      "array index is displayed as a number"
+    );
     is(TEST_ARRAY[name], row.value, `value for array[${name}] is ${row.value}`);
   }
 });
