@@ -8,7 +8,7 @@ http://creativecommons.org/publicdomain/zero/1.0/ */
 const TEST_URL = "data:text/html;charset=utf-8,DevicePixelRatio list test";
 const DEFAULT_DPPX = window.devicePixelRatio;
 const VIEWPORT_DPPX = DEFAULT_DPPX + 1;
-const Types = require("devtools/client/responsive/types");
+const Types = require("resource://devtools/client/responsive/types.js");
 
 const testDevice = {
   name: "Fake Phone RDM Test",
@@ -27,12 +27,12 @@ addDeviceForTest(testDevice);
 
 addRDMTask(
   TEST_URL,
-  async function({ ui, manager }) {
+  async function ({ ui }) {
     await waitStartup(ui);
 
     await testDefaults(ui);
     await testChangingDevice(ui);
-    await testResetWhenResizingViewport(ui);
+    await testResizingViewport(ui);
     await testChangingDevicePixelRatio(ui);
   },
   { waitForDeviceList: true }
@@ -76,23 +76,27 @@ async function testChangingDevice(ui) {
   testViewportDeviceMenuLabel(ui, testDevice.name);
 }
 
-async function testResetWhenResizingViewport(ui) {
-  info("Test reset when resizing the viewport");
+async function testResizingViewport(ui) {
+  info("Test resizing the viewport");
 
-  const deviceRemoved = once(ui, "device-association-removed");
   await testViewportResize(
     ui,
     ".viewport-vertical-resize-handle",
     [-10, -10],
-    [0, -10]
+    [0, -10],
+    {
+      hasDevice: true,
+    }
   );
-  await deviceRemoved;
 
-  const dppx = await waitForDevicePixelRatio(ui, DEFAULT_DPPX);
-  is(dppx, DEFAULT_DPPX, "Content has expected devicePixelRatio");
+  // Wait for a bit to let enough time to a change in dpr to happen
+  await wait(1000);
+
+  const dppx = await getViewportDevicePixelRatio(ui);
+  is(dppx, testDevice.pixelRatio, "Content has expected devicePixelRatio");
 
   testViewportDevicePixelRatioSelect(ui, {
-    value: DEFAULT_DPPX,
+    value: testDevice.pixelRatio,
     disabled: false,
   });
   testViewportDeviceMenuLabel(ui, "Responsive");
