@@ -8,9 +8,11 @@ const TEST_URI =
   "data:text/html;charset=utf-8,<head>" +
   "<link rel='stylesheet' type='text/css' href='chrome://devtools/skin/widg" +
   "ets.css'></head><body><div></div><span></span></body>";
-const { TreeWidget } = require("devtools/client/shared/widgets/TreeWidget");
+const {
+  TreeWidget,
+} = require("resource://devtools/client/shared/widgets/TreeWidget.js");
 
-add_task(async function() {
+add_task(async function () {
   await SpecialPowers.pushPrefEnv({
     set: [["security.allow_unsafe_parent_loads", true]],
   });
@@ -32,7 +34,7 @@ add_task(async function() {
   gBrowser.removeCurrentTab();
 });
 
-function populateTree(tree, doc) {
+function populateTree(tree) {
   tree.add([
     {
       id: "level1",
@@ -144,7 +146,7 @@ function testTreeItemInsertedCorrectly(tree, doc) {
   tree.add([
     {
       id: "level1.2",
-      node: node,
+      node,
       attachment: {
         foo: "bar",
       },
@@ -177,7 +179,7 @@ function testTreeItemInsertedCorrectly(tree, doc) {
 /**
  * Populate the unsorted tree.
  */
-function populateUnsortedTree(tree, doc) {
+function populateUnsortedTree(tree) {
   tree.sorted = false;
 
   tree.add([{ id: "g-1", label: "g-1" }]);
@@ -189,7 +191,7 @@ function populateUnsortedTree(tree, doc) {
 /**
  * Test if the nodes are inserted correctly in the unsorted tree.
  */
-function testUnsortedTreeItemInsertedCorrectly(tree, doc) {
+function testUnsortedTreeItemInsertedCorrectly(tree) {
   ok(tree.root.items.has("g-1"), "g-1 top level element exists");
 
   is(
@@ -287,7 +289,7 @@ function testAPI(tree, doc) {
   );
 
   // test if collapseAll/expandAll work
-  ok(doc.querySelectorAll("[expanded]").length > 0, "Some nodes are expanded");
+  ok(!!doc.querySelectorAll("[expanded]").length, "Some nodes are expanded");
   tree.collapseAll();
   is(
     doc.querySelectorAll("[expanded]").length,
