@@ -6,19 +6,17 @@
 // Test that we can tell the memory actor to take a heap snapshot over the RDP
 // and then create a HeapSnapshot instance from the resulting file.
 
-const { OS } = require("resource://gre/modules/osfile.jsm");
-
 add_task(async () => {
   const { memoryFront } = await createTabMemoryFront();
 
   const snapshotFilePath = await memoryFront.saveHeapSnapshot();
   ok(
-    !!(await OS.File.stat(snapshotFilePath)),
+    !!(await IOUtils.stat(snapshotFilePath)),
     "Should have the heap snapshot file"
   );
   const snapshot = ChromeUtils.readHeapSnapshot(snapshotFilePath);
   ok(
-    snapshot instanceof HeapSnapshot,
+    HeapSnapshot.isInstance(snapshot),
     "And we should be able to read a HeapSnapshot instance from the file"
   );
 });
